@@ -97,11 +97,11 @@ Not required
 
 ### Response
 
-```
-Status:       <: $result.status :>
-Content-Type: <: $result.response_content_type :>
-Response:
+- Status:       <: $result.status :>
+- Content-Type: <: $result.response_content_type :>
+
+```json
 <: $result.response_body :>
-: }
 ```
 
+: }
